The following tasks implement working memory paradigms:

- [DelayComparison](../envs.md#neurogym.envs.native.delaycomparison.DelayComparison)
- [DelayMatchCategory](../envs.md#neurogym.envs.native.delaymatchcategory.DelayMatchCategory)
- [DelayMatchSample](../envs.md#neurogym.envs.native.delaymatchsample.DelayMatchSample)
- [DelayMatchSampleDistractor1D](../envs.md#neurogym.envs.native.delaymatchsample.DelayMatchSampleDistractor1D)
- [DelayPairedAssociation](../envs.md#neurogym.envs.native.delaypairedassociation.DelayPairedAssociation)
- [DualDelayMatchSample](../envs.md#neurogym.envs.native.dualdelaymatchsample.DualDelayMatchSample)
- [IntervalDiscrimination](../envs.md#neurogym.envs.native.intervaldiscrimination.IntervalDiscrimination)
